<?php
/*
Plugin Name: WP Greet Box
Plugin URI: http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/
Description: Show a different message to your visitor depending on which site they are coming from.  For example, you can ask Digg visitors to Digg your post, Google visitors to subscribe to your RSS feed, and more!  Best of all, this plugin is compatible with various WordPress cache plugins.
Version: 3.0
Author: Thaya Kareeson
Author URI: http://omninoggin.com/
*/

/*
Copyright 2008 Thaya Kareeson (email : thaya.kareeson@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class wp_greet_box {

  function get_default_options() {
    return array(
      'before_greet'           => '<div class="greet_block">',
      'after_greet'            => '</div><div style="clear:both"></div>',
      'before_icon'            => '<div class="greet_image">',
      'after_icon'             => '</div>',
      'before_text'            => '<div class="greet_text">',
      'after_text'             => '</div>',
      'rss_link'               => get_bloginfo('rss_url'),
      'message_default'        => array(
        'disable' => 0,
        'icon' => wp_greet_box::get_plugin_url().'/images/'.'rss_icon.png',
        'timeout' => 14400,
        'text' => 'Hello there! If you are new here, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
      ),
      'messages'               => array(
        array(
          'referrer' => 'del.icio.us',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'delicious_icon.png',
          'timeout' => 0,
          'text' => 'Hello fellow <strong>del.icio.us</strong> user! Feel free to <a href="http://del.icio.us/post?url=[[escaped-permalink]]" rel="nofollow"><strong>bookmark this page</strong></a> for future reference if you like it!'
        ),
        array(
          'referrer' => 'digg.com',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'digg_icon.png',
          'timeout' => 0,
          'text' => 'Hello fellow <strong>Digger</strong>! If you like this page, don\'t forget to <a href="http://digg.com/submit?url=[[escaped-permalink]]" rel="nofollow"><strong>digg it</strong></a>!'
        ),
        array(
          'referrer' => 'google.com',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'google_icon.png',
          'timeout' => 1440,
          'text' => 'Welcome <strong>Googler</strong>! If you find this page useful, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
        ),
        array(
          'referrer' => 'stumbleupon.com',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'stumbleupon_icon.png',
          'timeout' => 0,
          'text' => 'Hello fellow <strong>Stumbler</strong>! Don\'t forget to <a href="http://www.stumbleupon.com/submit?url=[[escaped-permalink]]" rel="nofollow"><strong>give me a thumbs up</strong></a> if you like this page!'
        ),
        array(
          'referrer' => 'technorati.com',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'technorati_icon.png',
          'timeout' => 0,
          'text' => 'Hello fellow <strong>Technorati</strong> user! Don\'t forget to <a href="http://technorati.com/faves?add=[[escaped-permalink]]" rel="nofollow"><strong>favorite this blog</strong></a> if you like it!'
        ),
        array(
          'referrer' => 'twitter.com',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'twitter_icon.png',
          'timeout' => 0,
          'text' => 'Hello fellow <strong>Twitter</strong> user! Don\'t forget to <a href="http://twitthis.com/twit?url=[[escaped-permalink]]" rel="nofollow"><strong>Twit this post</strong></a> if you like it, or <a href="http://twitter.com/" rel="nofollow"><strong>follow me</strong></a> on Twitter if you find me interesting.'
        ),
        array(
          'referrer' => 'yahoo.com',
          'disable' => 0,
          'icon' => wp_greet_box::get_plugin_url().'/images/'.'rss_icon.png',
          'timeout' => 1440,
          'text' => 'Welcome fellow <strong>Yahooligan</strong>! If you find this page useful, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
        )
      )
    );
  }

  function activate() {
    if ( !get_option('wp_greet_box') ) {
      // set default options if no options exist
      add_option( 'wp_greet_box', wp_greet_box::get_default_options() );
    }
    // generate the JS file upon activation
    wp_greet_box::generate_greet_js();
  }

  function update_options() {
    $wp_greet_box_options = stripslashes_deep($_POST['wpgreetbox']);

    // convert "on" to 1 and "off" to 0 for checkbox fields
    // and set defaults for fields that are left blank
    // nasty-looking loop necessary for PHP4 backwards compatibility
    $keys = array_keys($wp_greet_box_options['messages']);
    $values = array_values($wp_greet_box_options['messages']);
    for ( $i = 0; $i <= count($wp_greet_box_options['messages']) - 1; $i++) {
      if ( $wp_greet_box_options['messages'][$keys[$i]]['disable'] == 'off' )
        $wp_greet_box_options['messages'][$keys[$i]]['disable'] = 0;
      elseif ( $wp_greet_box_options['messages'][$keys[$i]]['disable'] == 'on' )
        $wp_greet_box_options['messages'][$keys[$i]]['disable'] = 1;
      if ( !$wp_greet_box_options['messages'][$keys[$i]]['timeout'] )
        $wp_greet_box_options['messages'][$keys[$i]]['timeout'] = 0;
    }

    // set defaults if some fields that are left blank
    if ( !$wp_greet_box_options['rss_link'] )
      $wp_greet_box_options['rss_link'] = get_bloginfo('rss_url');

    // Update options
    update_option( 'wp_greet_box', $wp_greet_box_options );
  }

  function add_greeting_message() {
    $wp_greet_box_options = get_option('wp_greet_box');
    $add_greet_box = stripslashes_deep($_POST['addgreetbox']);
    $add_greet_box['disable'] = false;
    $wp_greet_box_options['messages'][] = $add_greet_box;

    // Update options
    update_option( 'wp_greet_box', $wp_greet_box_options );
  }

  function delete_greeting_message() {
    $wp_greet_box_options = get_option('wp_greet_box');
    $greet_box_id = $_POST['actiongreetid'];
    // delete item
    unset($wp_greet_box_options['messages'][$greet_box_id]);
    // reindex
    $wp_greet_box_options['messages'] = array_values($wp_greet_box_options['messages']);

    // Update options
    update_option( 'wp_greet_box', $wp_greet_box_options );
  }

  function reset_options() {
    if ( !get_option('wp_greet_box') ) {
      add_option( 'wp_greet_box', wp_greet_box::get_default_options() );
    }
    else {
      update_option( 'wp_greet_box', wp_greet_box::get_default_options() );
    }
  }

  function get_plugin_dir() {
    // Pre-2.6 compatibility
    if ( !defined('WP_CONTENT_DIR') )
      define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
    return WP_CONTENT_DIR.'/plugins/'.plugin_basename(dirname(__FILE__));
  }

  function get_plugin_url() {
    // Pre-2.6 compatibility
    if ( !defined('WP_CONTENT_URL') )
      define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
    return WP_CONTENT_URL.'/plugins/'.plugin_basename(dirname(__FILE__));
  }

  function get_current_page_url() {
    $isHTTPS = (isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on");
    $port = (isset($_SERVER["SERVER_PORT"]) && ((!$isHTTPS && $_SERVER["SERVER_PORT"] != "80") || ($isHTTPS && $_SERVER["SERVER_PORT"] != "443")));
    $port = ($port) ? ':'.$_SERVER["SERVER_PORT"] : '';
    $url = ($isHTTPS ? 'https://' : 'http://').$_SERVER["SERVER_NAME"].$port.$_SERVER["REQUEST_URI"];
    return $url;
  }

  function get_icon_html($icon_file) {
    return '<img src="'.$icon_file.'"/>';
  }

  function get_greet_html($icon_file, $text) {
    extract(get_option('wp_greet_box'));
    $greet_html  = '<div id="greet_block">'.$before_greet.$before_text;
    if ( strlen ( $icon_file ) > 0 ) {
      // do not show icon if there is no icon url
      $greet_html .= $before_icon.wp_greet_box::get_icon_html($icon_file).$after_icon;
    }
    $greet_html .= $text.$after_text.'<div class="greet_block_close"><a>X</a></div>'.$after_greet.'</div>';
    $greet_html  = str_replace('[[rss-link]]', $rss_link, $greet_html);
    $greet_html  = str_replace('[[escaped-permalink]]', rawurlencode(wp_greet_box::get_current_page_url()), $greet_html);
    return $greet_html;
  }

  function get_greet_js($icon_file, $text) {
    extract(get_option('wp_greet_box'));
    $greet_js = '<div id="greet_block">'.$before_greet.$before_text;
    if ( strlen ( $icon_file ) > 0 ) {
      // do not show icon if there is no icon url
      $greet_js .= $before_icon.wp_greet_box::get_icon_html($icon_file).$after_icon;
    }
    $greet_js .= $text.$after_text.'<div class="greet_block_close"><a onclick="wpgb_close()">X</a></div>'.$after_greet.'</div>';
    $greet_js  = str_replace('\'', '\\\'', $greet_js);
    $greet_js  = str_replace('[[rss-link]]', $rss_link, $greet_js);
    $greet_js  = str_replace('[[escaped-permalink]]', '\'+escape(window.location.href)+\'&title=\'+escape(document.title)+\'', $greet_js);
    return $greet_js;
  }

  function generate_greet_js() {
    extract(get_option('wp_greet_box'));

    $file_content = '
      //---------------------------------------------------------------------//
      // This file is automatically generated.  Any changes here will be     //
      // overwriten by WP-Greet-Box configuration options.                   //
      //---------------------------------------------------------------------//

      var wpgb_cookie_exp = 365;
      var wpgb_greetings = new Array();
    ';

    if ( $message_default['text'] != '' && !$message_default['disable'] ) {
      $file_content .= '
        var wpgb_default_timeout = '.$message_default['timeout'].';
        var wpgb_default_greeting = \''.wp_greet_box::get_greet_js($message_default['icon'], $message_default['text']).'\';
      ';
    }
    else {
      $file_content .= '
        var wpgb_default_timeout;
        var wpgb_default_greeting;
      ';
    }

    foreach ( $messages as $message ) {
      if ( strlen ( $message['text'] ) > 0 && !$message['disable'] ) {
        $file_content .= '
          wpgb_greetings["'.$message['referrer'].'"] = new Array();
          wpgb_greetings["'.$message['referrer'].'"]["message"] = \''.wp_greet_box::get_greet_js($message['icon'], $message['text']).'\';
        ';
        if ( $message['timeout'] ) {
          $file_content .= 'wpgb_greetings["'.$message['referrer'].'"]["timeout"] = '.$message['timeout'].';';
        }
        else {
          $file_content .= 'wpgb_greetings["'.$message['referrer'].'"]["timeout"] = 0;';
        }
      }
    }

    $file_content .= '
      function wpgb_get_cookie(c_name) {
        if (document.cookie.length>0) {
          c_start=document.cookie.indexOf(c_name + "=");
          if (c_start!=-1) {
            c_start=c_start + c_name.length+1;
            c_end=document.cookie.indexOf(";",c_start);
            if (c_end==-1) c_end=document.cookie.length;
            return unescape(document.cookie.substring(c_start,c_end));
          }
        }
        return "";
      }
      
      function wpgb_set_cookie(c_name,value,expiredays) {
        var exdate = new Date();
        exdate.setDate(exdate.getDate()+expiredays);
        document.cookie=c_name+ "=" +escape(value)+";path="+"/"+
        ((expiredays==null) ? "" : ";expires="+exdate.toGMTString());
      }
      
      function wpgb_delete_cookie ( c_name )
      {
        var now = new Date ();
        now.setTime ( now.getTime() - 1 );
        document.cookie = c_name += "=; expires=" + now.toGMTString();
      }
      
      function wpgb_close() {
        var wpgb_el = document.getElementById("greet_block");
        if(wpgb_el)
          wpgb_el.style.display = "none";
      }

      function wpgb_get_delta(ref) {
        var visit_delta;
        var visit_last = wpgb_get_cookie("wpgb_visit_last-"+ref);

        if(visit_last==null || visit_last=="") {
          visit_delta = -1;
        }
        else {
          visit_last = new Date(visit_last);
          visit_delta = Math.round((new Date() - visit_last)/(1000 * 60));
        }
        return visit_delta;
      }
      
      function wpgb_display() {
        for(var i in wpgb_greetings){
          if(document.referrer.indexOf(i) > -1) {
            var visit_delta = wpgb_get_delta(i);

            wpgb_set_cookie("wpgb_visit_last-"+i,new Date(),wpgb_cookie_exp);
            if(visit_delta < 0 || visit_delta >= wpgb_greetings[i]["timeout"]) {
              document.write(wpgb_greetings[i]["message"]);
              return;
            }
          }
        }

        var visit_delta = wpgb_get_delta("default");

        wpgb_set_cookie("wpgb_visit_last-default",new Date(),wpgb_cookie_exp);
        if(wpgb_default_greeting != null && wpgb_default_greeting != ""
          &&(visit_delta < 0 || visit_delta >= wpgb_default_timeout)
        ) {
          document.write(wpgb_default_greeting);
        }
      }
      
      wpgb_display();
    ';

    $file_name = wp_greet_box::get_plugin_dir().'/wp-greet-box.js';
    $fh = fopen($file_name, 'w+') or die("Cannot open file '$file_name' for write");
    fwrite($fh, $file_content);
    fclose($fh);
  }

  function display_wp_greet_box() {
    echo '<link rel="stylesheet" href="'.wp_greet_box::get_plugin_url().'/wp-greet-box.css" type="text/css"/>';
    echo '<script type="text/javascript" src="'.wp_greet_box::get_plugin_url().'/wp-greet-box.js"></script>';
  }

  function admin_menu() {
    add_options_page( 'WP Greet Box', 'WP Greet Box', 'manage_options', 'wp-greet-box-admin', array('wp_greet_box', 'admin_page') );
  }

  function admin_page() {
    if ( isset($_POST['wp_greet_box_options_submit']) ) {
      // if user submits information
      check_admin_referer( 'wp_greet_box' );
      wp_greet_box::update_options();
      echo '<div class="updated fade"><p>WP Greet Box options updated.</p></div>';
    }
    elseif ( isset($_POST['wp_greet_box_options_reset']) ) {
      // if user wants to reset all options
      check_admin_referer( 'wp_greet_box' );
      wp_greet_box::reset_options();
      echo '<div class="updated fade"><p>WP Greet Box options has been reset.</p></div>';
    }
    elseif ( isset($_POST['wp_greet_box_options_add']) ) {
      // if user wants to add a new custom greeting message
      check_admin_referer( 'wp_greet_box' );
      wp_greet_box::add_greeting_message();
      echo '<div class="updated fade"><p>Added an additional greeting message.</p></div>';
    }
    elseif ( isset($_POST['wp_greet_box_options_delete']) ) {
      // if user wants to delete a new custom greeting message
      check_admin_referer( 'wp_greet_box' );
      wp_greet_box::delete_greeting_message();
      echo '<div class="updated fade"><p>Greeting message deleted.</p></div>';
    }
    wp_greet_box::generate_greet_js();
    extract(get_option('wp_greet_box'));
?>
      <link rel='stylesheet' href='<?php echo wp_greet_box::get_plugin_url() ?>/wp-greet-box.css' type='text/css'/>
      <style type='text/css'>
        .wpgreetbox-focusable:focus { background-color: #ffc }
        .wpgb_fieldset {
          border:1px solid #ccc;
          margin:10px;
          padding:20px;
        }
        .wpgb_fieldset_alt {
          background:#f6f6f6;
        }
        dl { margin-left: 3em }
      </style>
      <script type="text/javascript">
        function confirm_delete(actiongreetid) {
          var answer = confirm("Are you sure you want to delete this custom message?");
          if(answer) {
            document.getElementById("actiongreetid").value = actiongreetid;
            return true;
          }
          else
            return false;
        }
        function confirm_reset() {
          var answer = confirm("Are you sure you want to reset all settings?  All of your new custom messages will be lost.");
          if(answer)
            return true;
          else
            return false;
        }
      </script>
      <div class="wrap">
      <h2>WP Greet Box Options</h2>
      <form method="post">
      <fieldset>
        <?php
          extract(get_option('wp_greet_box'));
        ?>
        <h3>Tips on Customizing Messages</h3>
        <fieldset class="wpgb_fieldset wpgb_fieldset_alt">
          <ol>
            <li>
              <p>Enter the markup for each message per referrer.  The following special tags are available.</p>
              <dl>
                <dt>[[rss-link]]</dt>
                <dd>The URL of your RSS feed.  You can also manually set this in the "Customize Display Box" section.</dd>
                <dt>[[escaped-permalink]]</dt>
                <dd>The escaped version of the current page's URL.</dd>
              </dl>
            </li>
            <li>
              <p>To customize the CSS property of the greet box, modify<br/>
                <strong><?php echo wp_greet_box::get_plugin_dir().'/wp-greet-box.css' ?></strong>.
              </p>
            </li>
            <li>
              <p><strong>Visitor Timeout</strong> is the number of minutes since the visitor's last visit until the plugin forgets the visitor.  For sites like digg.com you would want to set this setting to something small like "0", because you would want the digg.com visitor to always see the request to be dugg on every visit.  For sites like google.com you might want to set it to something higher like "1440" (1 day) because you probably do not want to nag the google visitor that much.  Play around with the values to see what suits you best.<br/>
              </p>
            </li>
          </ol>
        </fieldset>
        <h3>Default Message</h3>
        <fieldset class="wpgb_fieldset wpgb_fieldset_alt">
          <label for="wpgreetbox-message-default">
            <?php
              if ( $message_default['disable'] )
                $checkmark = 'checked';
              else
                $checkmark = '';
            ?>
            Disable? <input name="wpgreetbox[message_default][disable]" id="wpgreetbox-message-default-disable" type="checkbox" <?php echo $checkmark; ?>/><br/><br/>
            Visitor Timeout:&nbsp;
            <input name="wpgreetbox[message_default][timeout]" id="wpgreetbox-message-default-timeout" type="text" class="wpgreetbox-focusable" value="<?php echo $message_default['timeout']; ?>"/>&nbsp;minutes<br/><br/>
            Prepend the greeting message with the following image:
            <input name="wpgreetbox[message_default][icon]" id="wpgreetbox-message-default-icon" type="text" class="wpgreetbox-focusable widefat" value="<?php echo wp_greet_box::get_plugin_url().'/images/'.'rss_icon.png' ?>"/><br/><br/>
            Show the following greeting message:
            <textarea name="wpgreetbox[message_default][text]" id="wpgreetbox-message-default-text" class="wpgreetbox-focusable widefat" rows="4"><?php echo $message_default['text'] ?></textarea><br/><br/>
            <?php
              if ( strlen ( $message_default['text'] ) > 0 ) {
                echo 'Preview:';
                echo wp_greet_box::get_greet_html($message_default['icon'], $message_default['text']);
              }
            ?>
          </label>
        </fieldset>
        <h3>Customize Messages</h3>
        <?php
          if ( sizeof($messages) > 0 ) {
            echo '<input name="actiongreetid" id="actiongreetid" type="hidden" value=""/>';
            foreach ( $messages as $key => $message ) {
              if($oddmessage == 'wpgb_fieldset_alt')
                $oddmessage = '';
              else
                $oddmessage = 'wpgb_fieldset_alt';
              echo '<fieldset class="wpgb_fieldset '.$oddmessage.'">';
              echo '<label for="wpgreetbox-messages-'.$key.'"><strong>'.$key.'.</strong>&nbsp;&nbsp;';
              echo 'Settings for referrer URL ';
              echo '<input name="wpgreetbox[messages]['.$key.'][referrer]" id="wpgreetbox-messages-'.$key.'-referrer" type="text" class="wpgreetbox-focusable" value="'.attribute_escape($message['referrer']).'"/>';
              if ( $message['disable'] )
                $checkmark = 'checked';
              else
                $checkmark = '';
              echo '&nbsp;&nbsp;Disable? <input name="wpgreetbox[messages]['.$key.'][disable]" id="wpgreetbox-messages-'.$key.'-disable" type="checkbox" '.$checkmark.'"/><br/><br/>';
              echo 'Visitor Timeout:&nbsp;';
              echo '<input name="wpgreetbox[messages]['.$key.'][timeout]" id="wpgreetbox-messages-'.$key.'-timeout" type="text" class="wpgreetbox-focusable" value="'.attribute_escape($message['timeout']).'"/>&nbsp;minutes<br/><br/>';
              echo 'Prepend the greeting message with the following image:';
              echo '<input name="wpgreetbox[messages]['.$key.'][icon]" id="wpgreetbox-messages-'.$key.'-icon" type="text" class="wpgreetbox-focusable widefat" value="'.attribute_escape($message['icon']).'"/><br/><br/>';
              echo 'Show the following greeting message:';
              echo '<textarea name="wpgreetbox[messages]['.$key.'][text]" id="wpgreetbox-messages-'.$key.'-text" class="wpgreetbox-focusable widefat" rows="4">'.attribute_escape($message['text']).'</textarea><br/><br/>';
              if ( strlen ( $message['text'] ) > 0 ) {
                echo 'Preview:';
                echo wp_greet_box::get_greet_html($message['icon'], $message['text']);
              }
              echo '<p class="submit">';
              echo '<input type="submit" name="wp_greet_box_options_delete" value="DELETE this message &#187;" onclick="return confirm_delete('.$key.')"/>';
              echo '</p>';
              echo '</label>';
              echo '</fieldset>';
            }
          }
          else {
            echo 'No custom messages yet. Use the section below to add one';
          }
        ?>
        <h3>New Custom Message</h3>
        <fieldset class="wpgb_fieldset wpgb_fieldset_alt">
          <label for="addgreetbox">
            Settings for referrer URL
            <input name="addgreetbox[referrer]" id="addgreetbox-referrer" type="text" class="addgreetbox-focusable" value="example.com"/><br/><br/>
            Visitor Timeout:&nbsp;
            <input name="addgreetbox[timeout]" id="addgreetbox-timeout" type="text" class="wpgreetbox-focusable" value="0"/>&nbsp;minutes<br/><br/>
            Prepend the greeting message with the following image:
            <input name="addgreetbox[icon]" id="addgreetbox-icon" type="text" class="addgreetbox-focusable widefat" value="<?php echo wp_greet_box::get_plugin_url().'/images/'.'rss_icon.png' ?>"/><br/><br/>';
            Show the following greeting message:
            <textarea name="addgreetbox[text]" id="addgreetbox-text" class="addgreetbox-focusable widefat" rows="4">Welcome <strong>example.com</strong> user! If you find this page useful, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.</textarea><br/><br/>
            <p class="submit"><input type="submit" name="wp_greet_box_options_add" value="Add this message &#187;" /></p>
          </label>
        </fieldset>
        <h3>Customize Display Box</h3>
        <fieldset class="wpgb_fieldset wpgb_fieldset_alt">
        <p>
          <label for="rss-url">Your RSS feed URL. (in case you syndicate your feed via a 3rd party service)<br/>
          <input name="wpgreetbox[rss_link]" id="rss-url" type="text" class="wpgreetbox-focusable widefat" value="<?php echo attribute_escape($rss_link); ?>"/></label>
        </p>
        <p>
          <label for="before-greet">HTML code to display before the greeting box.<br/>
          <textarea name="wpgreetbox[before_greet]" id="before-greet" class="wpgreetbox-focusable widefat" rows="2"><?php echo attribute_escape($before_greet); ?></textarea></label>
        </p>
        <p>
          <label for="after-greet">HTML code to display after the greeting box.<br/>
          <textarea name="wpgreetbox[after_greet]" id="after-greet" class="wpgreetbox-focusable widefat" rows="2"><?php echo attribute_escape($after_greet); ?></textarea></label>
        </p>
        <p>
          <label for="before-icon">HTML code to display before the image in the greeting box.<br/>
          <textarea name="wpgreetbox[before_icon]" id="before-icon" class="wpgreetbox-focusable widefat" rows="2"><?php echo attribute_escape($before_icon); ?></textarea></label>
        </p>
        <p>
          <label for="after-icon">HTML code to display after the image in the greeting box.<br/>
          <textarea name="wpgreetbox[after_icon]" id="after-icon" class="wpgreetbox-focusable widefat" rows="2"><?php echo attribute_escape($after_icon); ?></textarea></label>
        </p>
        <p>
          <label for="before-text">HTML code to display before the text in the greeting box.<br/>
          <textarea name="wpgreetbox[before_text]" id="before-text" class="wpgreetbox-focusable widefat" rows="2"><?php echo attribute_escape($before_text); ?></textarea></label>
        </p>
        <p>
          <label for="after-text">HTML code to display after the text in the greeting box.<br/>
          <textarea name="wpgreetbox[after_text]" id="after-text" class="wpgreetbox-focusable widefat" rows="2"><?php echo attribute_escape($after_text); ?></textarea></label>
        </p>
        </fieldset>
      </fieldset>
      <?php if ( function_exists( 'wp_nonce_field' ) ) wp_nonce_field( 'wp_greet_box' ); ?>
      <p class="submit">
        <input type="submit" name="wp_greet_box_options_submit" value="Update Options &#187;" />
        <input type="submit" name="wp_greet_box_options_reset" value="RESET Options &#187;" onclick="return confirm_reset()"/>
      </p>
      </form>
      </div>
<?php
  } // function admin_page()
} // class wp_greet_box

function wp_greet_box() {
  wp_greet_box::display_wp_greet_box();
}

if ( function_exists('add_action') ) {
  add_action('admin_menu', array('wp_greet_box', 'admin_menu') );
}

if ( function_exists('register_activation_hook') ) {
  register_activation_hook(__FILE__, array('wp_greet_box', 'activate'));
}
?>
